==> haskell-extra-1.6.17-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.17
id: extra-1.6.17-LxsmMzFIshh5HapqTGJ9mf
key: extra-1.6.17-LxsmMzFIshh5HapqTGJ9mf
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: 6610a6eae50dce77fca3a7bb0727e643
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.List.NonEmpty.Extra Data.Tuple.Extra
    Data.Typeable.Extra Data.Version.Extra Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.IO.Extra
    System.Info.Extra System.Process.Extra System.Time.Extra
    Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/extra-1.6.17
hs-libraries: HSextra-1.6.17-LxsmMzFIshh5HapqTGJ9mf
depends:
    base-4.12.0.0 clock-0.8-H1S1zDefxirImaRbI6ITNv directory-1.3.3.0
    filepath-1.4.2.1 process-1.6.5.0 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.6.17-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.17
id: extra-1.6.17-Gz9tBYjY7l0FvUCaVAXuat
key: extra-1.6.17-Gz9tBYjY7l0FvUCaVAXuat
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: 9a79e74cf4415aa8db85d5cef0977010
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.List.NonEmpty.Extra Data.Tuple.Extra
    Data.Typeable.Extra Data.Version.Extra Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.IO.Extra
    System.Info.Extra System.Process.Extra System.Time.Extra
    Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/extra-1.6.17
hs-libraries: HSextra-1.6.17-Gz9tBYjY7l0FvUCaVAXuat
depends:
    base-4.12.0.0 clock-0.8-H1S1zDefxirImaRbI6ITNv directory-1.3.3.0
    filepath-1.4.2.1 process-1.6.5.0 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
